A2AError

Struct A2AError 

pub struct A2AError {
    pub code: i32,
    pub message: String,
    pub details: Option<Vec<TypedDetail>>,
}
An A2A protocol error.

Fields

code: i32message: Stringdetails: Option<Vec<TypedDetail>>

Implementations

Source

impl A2AError

pub fn new(code: i32, message: impl Into<String>) -> Self

pub fn with_details(self, details: Vec<TypedDetail>) -> Self

pub fn task_not_found(task_id: &str) -> Self

pub fn task_not_cancelable(task_id: &str) -> Self

pub fn push_notification_not_supported() -> Self

pub fn unsupported_operation(msg: impl Into<String>) -> Self

pub fn content_type_not_supported() -> Self

pub fn invalid_agent_response() -> Self

pub fn version_not_supported(version: &str) -> Self

pub fn internal(msg: impl Into<String>) -> Self

pub fn invalid_params(msg: impl Into<String>) -> Self

pub fn parse_error(msg: impl Into<String>) -> Self

pub fn invalid_request(msg: impl Into<String>) -> Self

pub fn method_not_found(method: &str) -> Self

pub fn http_status_code(&self) -> u16

Map A2A error code to HTTP status code for REST binding.

pub fn to_jsonrpc_error(&self) -> JsonRpcError

Convert to a JSON-RPC error object.

The data field is always populated with an array of typed detail objects. An ErrorInfo detail (with reason, domain, and timestamp) is always appended as the last element, matching the Go SDK behavior.